about summary refs log tree commit diff
diff options
context:
space:
mode:
authorOndřej Bílka <neleai@seznam.cz>2013-08-30 18:09:30 +0200
committerOndřej Bílka <neleai@seznam.cz>2013-08-30 18:10:31 +0200
commitf24a6d086b96a65a73c68ecf349b03321cb03720 (patch)
tree823c4db1322b11c81ba5ce05d77adbf4afbdbbc8
parent382466e04e347d3b3fa221897efb8f4cdc239105 (diff)
downloadglibc-f24a6d086b96a65a73c68ecf349b03321cb03720.tar.gz
glibc-f24a6d086b96a65a73c68ecf349b03321cb03720.tar.xz
glibc-f24a6d086b96a65a73c68ecf349b03321cb03720.zip
Fix then/than typos.
-rw-r--r--ChangeLog16
-rw-r--r--csu/init-first.c2
-rw-r--r--locale/programs/ld-collate.c2
-rw-r--r--locale/programs/linereader.h2
-rw-r--r--manual/charset.texi2
-rw-r--r--manual/filesys.texi6
-rw-r--r--manual/stdio.texi2
-rw-r--r--manual/string.texi4
-rw-r--r--ports/ChangeLog.alpha4
-rw-r--r--ports/ChangeLog.mips4
-rw-r--r--ports/sysdeps/alpha/alphaev67/stpncpy.S2
-rw-r--r--ports/sysdeps/mips/memcpy.S14
-rw-r--r--stdlib/fmtmsg.c4
-rw-r--r--sysdeps/i386/stpncpy.S2
-rw-r--r--sysdeps/powerpc/powerpc32/power6/memcpy.S18
-rw-r--r--sysdeps/powerpc/powerpc32/power6/memset.S4
-rw-r--r--sysdeps/powerpc/powerpc64/power6/memcpy.S10
-rw-r--r--sysdeps/powerpc/powerpc64/power6/memset.S4
18 files changed, 63 insertions, 39 deletions
diff --git a/ChangeLog b/ChangeLog
index 8c4adb3829..6b299a1229 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,21 @@
 2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
 
+	* csu/init-first.c: Fix then/than typos.
+	* locale/programs/ld-collate.c: Likewise.
+	* locale/programs/linereader.h: Likewise.
+	* manual/charset.texi: Likewise.
+	* manual/filesys.texi: Likewise.
+	* manual/stdio.texi: Likewise.
+	* manual/string.texi: Likewise.
+	* stdlib/fmtmsg.c: Likewise.
+	* sysdeps/i386/stpncpy.S: Likewise.
+	* sysdeps/powerpc/powerpc32/power6/memcpy.S: Likewise.
+	* sysdeps/powerpc/powerpc32/power6/memset.S: Likewise.
+	* sysdeps/powerpc/powerpc64/power6/memcpy.S: Likewise.
+	* sysdeps/powerpc/powerpc64/power6/memset.S: Likewise.
+
+2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
+
 	* elf/dl-open.c: Fix typos.
 	* iconvdata/gbbig5.c: Likewise.
 	* iconvdata/iso-2022-jp.c: Likewise.
diff --git a/csu/init-first.c b/csu/init-first.c
index 89d8d9634b..f0ebc94b8d 100644
--- a/csu/init-first.c
+++ b/csu/init-first.c
@@ -29,7 +29,7 @@
 
 #include <ldsodefs.h>
 
-/* Set nonzero if we have to be prepared for more then one libc being
+/* Set nonzero if we have to be prepared for more than one libc being
    used in the process.  Safe assumption if initializer never runs.  */
 int __libc_multiple_libcs attribute_hidden = 1;
 
diff --git a/locale/programs/ld-collate.c b/locale/programs/ld-collate.c
index 6894a7c181..e58c8f7020 100644
--- a/locale/programs/ld-collate.c
+++ b/locale/programs/ld-collate.c
@@ -2674,7 +2674,7 @@ skip_to (struct linereader *ldfile, struct locale_collate_t *collate,
 	}
       else if (nowtok == tok_else)
 	{
-	  lr_error (ldfile, _("%s: more then one 'else'"), "LC_COLLATE");
+	  lr_error (ldfile, _("%s: more than one 'else'"), "LC_COLLATE");
 	}
 
       lr_ignore_rest (ldfile, 0);
diff --git a/locale/programs/linereader.h b/locale/programs/linereader.h
index e0475a2ef7..4e4fe9d874 100644
--- a/locale/programs/linereader.h
+++ b/locale/programs/linereader.h
@@ -49,7 +49,7 @@ struct token
     struct
     {
       /* This element is sized on the safe expectation that no single
-	 character in any character set uses more then 16 bytes.  */
+	 character in any character set uses more than 16 bytes.  */
       unsigned char bytes[16];
       int nbytes;
     } charcode;
diff --git a/manual/charset.texi b/manual/charset.texi
index e21502e5c8..4042639305 100644
--- a/manual/charset.texi
+++ b/manual/charset.texi
@@ -786,7 +786,7 @@ mbslen (const char *s)
 This function simply calls @code{mbrlen} for each multibyte character
 in the string and counts the number of function calls.  Please note that
 we here use @code{MB_LEN_MAX} as the size argument in the @code{mbrlen}
-call.  This is acceptable since a) this value is larger then the length of
+call.  This is acceptable since a) this value is larger than the length of
 the longest multibyte character sequence and b) we know that the string
 @var{s} ends with a NUL byte, which cannot be part of any other multibyte
 character sequence but the one representing the NUL wide character.
diff --git a/manual/filesys.texi b/manual/filesys.texi
index 814c210a93..1cac45393d 100644
--- a/manual/filesys.texi
+++ b/manual/filesys.texi
@@ -1909,7 +1909,7 @@ replaces the normal implementation.
 @comment Unix98
 @deftypefun int stat64 (const char *@var{filename}, struct stat64 *@var{buf})
 This function is similar to @code{stat} but it is also able to work on
-files larger then @math{2^31} bytes on 32-bit systems.  To be able to do
+files larger than @math{2^31} bytes on 32-bit systems.  To be able to do
 this the result is stored in a variable of type @code{struct stat64} to
 which @var{buf} must point.
 
@@ -1970,7 +1970,7 @@ replaces the normal implementation.
 @comment Unix98
 @deftypefun int lstat64 (const char *@var{filename}, struct stat64 *@var{buf})
 This function is similar to @code{lstat} but it is also able to work on
-files larger then @math{2^31} bytes on 32-bit systems.  To be able to do
+files larger than @math{2^31} bytes on 32-bit systems.  To be able to do
 this the result is stored in a variable of type @code{struct stat64} to
 which @var{buf} must point.
 
@@ -3152,7 +3152,7 @@ interface transparently replaces the old interface.
 @deftypefun {FILE *} tmpfile64 (void)
 This function is similar to @code{tmpfile}, but the stream it returns a
 pointer to was opened using @code{tmpfile64}.  Therefore this stream can
-be used for files larger then @math{2^31} bytes on 32-bit machines.
+be used for files larger than @math{2^31} bytes on 32-bit machines.
 
 Please note that the return type is still @code{FILE *}.  There is no
 special @code{FILE} type for the LFS interface.
diff --git a/manual/stdio.texi b/manual/stdio.texi
index 3f9be9bc58..30630caf6b 100644
--- a/manual/stdio.texi
+++ b/manual/stdio.texi
@@ -267,7 +267,7 @@ Locks}.
 @deftypefun {FILE *} fopen64 (const char *@var{filename}, const char *@var{opentype})
 This function is similar to @code{fopen} but the stream it returns a
 pointer for is opened using @code{open64}.  Therefore this stream can be
-used even on files larger then @math{2^31} bytes on 32 bit machines.
+used even on files larger than @math{2^31} bytes on 32 bit machines.
 
 Please note that the return type is still @code{FILE *}.  There is no
 special @code{FILE} type for the LFS interface.
diff --git a/manual/string.texi b/manual/string.texi
index 246be84457..2a164a9523 100644
--- a/manual/string.texi
+++ b/manual/string.texi
@@ -682,7 +682,7 @@ The behavior of @code{wcpcpy} is undefined if the strings overlap.
 This function is similar to @code{stpcpy} but copies always exactly
 @var{size} characters into @var{to}.
 
-If the length of @var{from} is more then @var{size}, then @code{stpncpy}
+If the length of @var{from} is more than @var{size}, then @code{stpncpy}
 copies just the first @var{size} characters and returns a pointer to the
 character directly following the one which was copied last.  Note that in
 this case there is no null terminator written into @var{to}.
@@ -707,7 +707,7 @@ declared in @file{string.h}.
 This function is similar to @code{wcpcpy} but copies always exactly
 @var{wsize} characters into @var{wto}.
 
-If the length of @var{wfrom} is more then @var{size}, then
+If the length of @var{wfrom} is more than @var{size}, then
 @code{wcpncpy} copies just the first @var{size} wide characters and
 returns a pointer to the wide character directly following the last
 non-null wide character which was copied last.  Note that in this case
diff --git a/ports/ChangeLog.alpha b/ports/ChangeLog.alpha
index 1bdd28fa0e..e5c7bc1da8 100644
--- a/ports/ChangeLog.alpha
+++ b/ports/ChangeLog.alpha
@@ -1,5 +1,9 @@
 2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
 
+	* sysdeps/alpha/alphaev67/stpncpy.S: Fix then/than typos.
+
+2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
+
 	* sysdeps/unix/sysv/linux/alpha/bits/netdb.h: Fix typos.
 
 2013-07-02  Richard Henderson  <rth@redhat.com>
diff --git a/ports/ChangeLog.mips b/ports/ChangeLog.mips
index d551974658..5844bf5897 100644
--- a/ports/ChangeLog.mips
+++ b/ports/ChangeLog.mips
@@ -1,5 +1,9 @@
 2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
 
+	* sysdeps/mips/memcpy.S: Fix then/than typos.
+
+2013-08-30   Ondřej Bílka  <neleai@seznam.cz>
+
 	* sysdeps/mips/memcpy.S: Fix typos.
 
 2013-08-29  Thomas Schwinge  <thomas@codesourcery.com>
diff --git a/ports/sysdeps/alpha/alphaev67/stpncpy.S b/ports/sysdeps/alpha/alphaev67/stpncpy.S
index 47841bbfa8..336db7dd00 100644
--- a/ports/sysdeps/alpha/alphaev67/stpncpy.S
+++ b/ports/sysdeps/alpha/alphaev67/stpncpy.S
@@ -16,7 +16,7 @@
    License along with the GNU C Library.  If not, see
    <http://www.gnu.org/licenses/>.  */
 
-/* Copy no more then N bytes from SRC to DEST, returning the address of
+/* Copy no more than N bytes from SRC to DEST, returning the address of
    the terminating '\0' in DEST.  */
 
 #include <sysdep.h>
diff --git a/ports/sysdeps/mips/memcpy.S b/ports/sysdeps/mips/memcpy.S
index 8065da3607..c7168476e0 100644
--- a/ports/sysdeps/mips/memcpy.S
+++ b/ports/sysdeps/mips/memcpy.S
@@ -155,14 +155,14 @@
  pref PREFETCH_STORE_HINT, (chunk)*32(reg)
 #endif
 /* MAX_PREFETCH_SIZE is the maximum size of a prefetch, it must not be less
- * then PREFETCH_CHUNK, the assumed size of each prefetch.  If the real size
- * of a prefetch is greater then MAX_PREFETCH_SIZE and the PREPAREFORSTORE
+ * than PREFETCH_CHUNK, the assumed size of each prefetch.  If the real size
+ * of a prefetch is greater than MAX_PREFETCH_SIZE and the PREPAREFORSTORE
  * hint is used, the code will not work correctly.  If PREPAREFORSTORE is not
  * used then MAX_PREFETCH_SIZE does not matter.  */
 #define MAX_PREFETCH_SIZE 128
 /* PREFETCH_LIMIT is set based on the fact that we never use an offset greater
- * then 5 on a STORE prefetch and that a single prefetch can never be larger
- * then MAX_PREFETCH_SIZE.  We add the extra 32 when USE_DOUBLE is set because
+ * than 5 on a STORE prefetch and that a single prefetch can never be larger
+ * than MAX_PREFETCH_SIZE.  We add the extra 32 when USE_DOUBLE is set because
  * we actually do two prefetches in that case, one 32 bytes after the other.  */
 #ifdef USE_DOUBLE
 # define PREFETCH_LIMIT (5 * PREFETCH_CHUNK) + 32 + MAX_PREFETCH_SIZE
@@ -275,7 +275,7 @@ LEAF(MEMCPY_NAME)
 L(memcpy):
 #endif
 /*
- * If the size is less then 2*NSIZE (8 or 16), go to L(lastb).  Regardless of
+ * If the size is less than 2*NSIZE (8 or 16), go to L(lastb).  Regardless of
  * size, copy dst pointer to v0 for the return value.
  */
 	slti	t2,a2,(2 * NSIZE)
@@ -443,7 +443,7 @@ L(chkw):
 	PTR_ADDIU a0,a0,UNIT(8)
 
 /*
- * Here we have less then 32(64) bytes to copy.  Set up for a loop to
+ * Here we have less than 32(64) bytes to copy.  Set up for a loop to
  * copy one word (or double word) at a time.  Set a2 to count how many
  * bytes we have to copy after all the word (or double word) chunks are
  * copied and a3 to the dst pointer after all the (d)word chunks have
@@ -635,7 +635,7 @@ L(ua_chkw):
 	C_ST	REG7,UNIT(7)(a0)
 	PTR_ADDIU a0,a0,UNIT(8)
 /*
- * Here we have less then 32(64) bytes to copy.  Set up for a loop to
+ * Here we have less than 32(64) bytes to copy.  Set up for a loop to
  * copy one word (or double word) at a time.
  */
 L(ua_chk1w):
diff --git a/stdlib/fmtmsg.c b/stdlib/fmtmsg.c
index 05344f0ada..5185de4272 100644
--- a/stdlib/fmtmsg.c
+++ b/stdlib/fmtmsg.c
@@ -116,9 +116,9 @@ fmtmsg (long int classification, const char *label, int severity,
       if (cp == NULL)
 	return MM_NOTOK;
 
-      /* The first field must not contain more then 10 bytes.  */
+      /* The first field must not contain more than 10 bytes.  */
       if (cp - label > 10
-	  /* The second field must not have more then 14 bytes.  */
+	  /* The second field must not have more than 14 bytes.  */
 	  || strlen (cp + 1) > 14)
 	return MM_NOTOK;
     }
diff --git a/sysdeps/i386/stpncpy.S b/sysdeps/i386/stpncpy.S
index 11882738d9..b23e8208a0 100644
--- a/sysdeps/i386/stpncpy.S
+++ b/sysdeps/i386/stpncpy.S
@@ -1,4 +1,4 @@
-/* copy no more then N bytes from SRC to DEST, returning the address of
+/* copy no more than N bytes from SRC to DEST, returning the address of
    the terminating '\0' in DEST.
    For Intel 80x86, x>=3.
    Copyright (C) 1994-2013 Free Software Foundation, Inc.
diff --git a/sysdeps/powerpc/powerpc32/power6/memset.S b/sysdeps/powerpc/powerpc32/power6/memset.S
index ce06630014..8c23c8d136 100644
--- a/sysdeps/powerpc/powerpc32/power6/memset.S
+++ b/sysdeps/powerpc/powerpc32/power6/memset.S
@@ -101,7 +101,7 @@ L(nondcbz):
    boundary may not be at cache line (128-byte) boundary.  */
 L(nzloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmplwi	cr1,rLEN,128
 
@@ -306,7 +306,7 @@ L(nzCacheAligned256):
    block zero instruction. */
 L(zloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmplwi	cr1,rLEN,128
 	beq	L(medium)
diff --git a/sysdeps/powerpc/powerpc64/power6/memset.S b/sysdeps/powerpc/powerpc64/power6/memset.S
index 541a45fd36..3e8ae2d25e 100644
--- a/sysdeps/powerpc/powerpc64/power6/memset.S
+++ b/sysdeps/powerpc/powerpc64/power6/memset.S
@@ -110,7 +110,7 @@ L(caligned):
    boundary may not be at cache line (128-byte) boundary.  */
 L(nzloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmpldi	cr1,rLEN,128
 
@@ -186,7 +186,7 @@ L(nzCacheAligned128):
    block zero instruction. */
 L(zloopstart):
 /* memset in 32-byte chunks until we get to a cache line boundary.
-   If rLEN is less then the distance to the next cache-line boundary use
+   If rLEN is less than the distance to the next cache-line boundary use
    cacheAligned1 code to finish the tail.  */
 	cmpldi	cr1,rLEN,128
 	beq	L(medium)
diff --git a/sysdeps/powerpc/powerpc32/power6/memcpy.S b/sysdeps/powerpc/powerpc32/power6/memcpy.S
index c3d55b7681..c7868069ab 100644
--- a/sysdeps/powerpc/powerpc32/power6/memcpy.S
+++ b/sysdeps/powerpc/powerpc32/power6/memcpy.S
@@ -269,7 +269,7 @@ L(wus_tail16): /* Move 16 bytes.  */
     addi  1,1,32
     blr
     .align  4
-L(wus_tail16p8):  /* less then 8 bytes left.  */
+L(wus_tail16p8):  /* less than 8 bytes left.  */
     beq   cr1,L(wus_tailX) /* exactly 16 bytes, early exit.  */
     cmplwi	cr1,10,20
     bf    29,L(wus_tail16p2)
@@ -283,7 +283,7 @@ L(wus_tail16p8):  /* less then 8 bytes left.  */
     addi  1,1,32
     blr
     .align  4
-L(wus_tail16p4):  /* less then 4 bytes left.  */
+L(wus_tail16p4):  /* less than 4 bytes left.  */
     addi  12,12,24
     addi  11,11,24
     bgt   cr0,L(wus_tail2)
@@ -291,7 +291,7 @@ L(wus_tail16p4):  /* less then 4 bytes left.  */
     addi  1,1,32
     blr
     .align  4
-L(wus_tail16p2):  /* 16 bytes moved, less then 4 bytes left.  */
+L(wus_tail16p2):  /* 16 bytes moved, less than 4 bytes left.  */
     addi  12,12,16
     addi  11,11,16
     b     L(wus_tail2)
@@ -315,7 +315,7 @@ L(wus_tail8):  /* Move 8 bytes.  */
     addi  1,1,32
     blr
     .align  4
-L(wus_tail8p4):  /* less then 4 bytes left.  */
+L(wus_tail8p4):  /* less than 4 bytes left.  */
     addi  12,12,8
     addi  11,11,8
     bgt   cr1,L(wus_tail2)
@@ -326,7 +326,7 @@ L(wus_tail8p4):  /* less then 4 bytes left.  */
     .align  4
 L(wus_tail4):  /* Move 4 bytes.  */
 /*  r6 already loaded speculatively.  If we are here we know there is
-    more then 4 bytes left.  So there is no need to test.  */
+    more than 4 bytes left.  So there is no need to test.  */
     addi  12,12,4
     stw   6,0(11)
     addi  11,11,4
@@ -426,14 +426,14 @@ L(wdu):
      First we need to copy word up to but not crossing the next 32-byte
      boundary. Then perform aligned loads just before and just after
      the boundary and use shifts and or to generate the next aligned
-     word for dst. If more then 32 bytes remain we copy (unaligned src)
-     the next 7 words and repeat the loop until less then 32-bytes
+     word for dst. If more than 32 bytes remain we copy (unaligned src)
+     the next 7 words and repeat the loop until less than 32-bytes
      remain.
 
-     Then if more then 4 bytes remain we again use aligned loads,
+     Then if more than 4 bytes remain we again use aligned loads,
      shifts and or to generate the next dst word. We then process the
      remaining words using unaligned loads as needed. Finally we check
-     if there more then 0 bytes (1-3) bytes remaining and use
+     if there more than 0 bytes (1-3) bytes remaining and use
      halfword and or byte load/stores to complete the copy.
 */
     mr      4,12      /* restore unaligned adjusted src ptr */
diff --git a/sysdeps/powerpc/powerpc64/power6/memcpy.S b/sysdeps/powerpc/powerpc64/power6/memcpy.S
index db29e2b065..d6d242d293 100644
--- a/sysdeps/powerpc/powerpc64/power6/memcpy.S
+++ b/sysdeps/powerpc/powerpc64/power6/memcpy.S
@@ -450,7 +450,7 @@ L(dus_tail16): /* Move 16 bytes.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p8):  /* less then 8 bytes left.  */
+L(dus_tail16p8):  /* less than 8 bytes left.  */
     beq   cr1,L(dus_tailX) /* exactly 16 bytes, early exit.  */
     cmpldi	cr1,10,20
     bf    29,L(dus_tail16p2)
@@ -464,7 +464,7 @@ L(dus_tail16p8):  /* less then 8 bytes left.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p4):  /* less then 4 bytes left.  */
+L(dus_tail16p4):  /* less than 4 bytes left.  */
     addi  12,12,24
     addi  3,3,24
     bgt   cr0,L(dus_tail2)
@@ -472,7 +472,7 @@ L(dus_tail16p4):  /* less then 4 bytes left.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail16p2):  /* 16 bytes moved, less then 4 bytes left.  */
+L(dus_tail16p2):  /* 16 bytes moved, less than 4 bytes left.  */
     addi  12,12,16
     addi  3,3,16
     b     L(dus_tail2)
@@ -497,7 +497,7 @@ L(dus_tail8):  /* Move 8 bytes.  */
     ld    3,-16(1)
     blr
     .align  4
-L(dus_tail8p4):  /* less then 4 bytes left.  */
+L(dus_tail8p4):  /* less than 4 bytes left.  */
     addi  12,12,8
     addi  3,3,8
     bgt   cr1,L(dus_tail2)
@@ -508,7 +508,7 @@ L(dus_tail8p4):  /* less then 4 bytes left.  */
     .align  4
 L(dus_tail4):  /* Move 4 bytes.  */
 /*  r6 already loaded speculatively.  If we are here we know there is
-    more then 4 bytes left.  So there is no need to test.  */
+    more than 4 bytes left.  So there is no need to test.  */
     addi  12,12,4
     stw   6,0(3)
     addi  3,3,4